# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/control/proto/lon_controller_conf.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.control.proto import calibration_table_pb2 as modules_dot_control_dot_proto_dot_calibration__table__pb2
from modules.control.proto import leadlag_conf_pb2 as modules_dot_control_dot_proto_dot_leadlag__conf__pb2
from modules.control.proto import pid_conf_pb2 as modules_dot_control_dot_proto_dot_pid__conf__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/control/proto/lon_controller_conf.proto',
  package='apollo.control',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n/modules/control/proto/lon_controller_conf.proto\x12\x0e\x61pollo.control\x1a-modules/control/proto/calibration_table.proto\x1a(modules/control/proto/leadlag_conf.proto\x1a$modules/control/proto/pid_conf.proto\"!\n\nFilterConf\x12\x13\n\x0b\x63utoff_freq\x18\x01 \x01(\x05\"\xec\x06\n\x11LonControllerConf\x12\n\n\x02ts\x18\x01 \x01(\x01\x12\x1c\n\x14\x62rake_minimum_action\x18\x02 \x01(\x01\x12\x1f\n\x17throttle_minimum_action\x18\x03 \x01(\x01\x12$\n\x1cspeed_controller_input_limit\x18\x04 \x01(\x01\x12\x1b\n\x13station_error_limit\x18\x05 \x01(\x01\x12\x16\n\x0epreview_window\x18\x06 \x01(\x01\x12\x1f\n\x17standstill_acceleration\x18\x07 \x01(\x01\x12\x31\n\x10station_pid_conf\x18\x08 \x01(\x0b\x32\x17.apollo.control.PidConf\x12\x33\n\x12low_speed_pid_conf\x18\t \x01(\x0b\x32\x17.apollo.control.PidConf\x12\x34\n\x13high_speed_pid_conf\x18\n \x01(\x0b\x32\x17.apollo.control.PidConf\x12\x14\n\x0cswitch_speed\x18\x0b \x01(\x01\x12\x39\n\x18reverse_station_pid_conf\x18\x0c \x01(\x0b\x32\x17.apollo.control.PidConf\x12\x37\n\x16reverse_speed_pid_conf\x18\r \x01(\x0b\x32\x17.apollo.control.PidConf\x12;\n\x17pitch_angle_filter_conf\x18\x0e \x01(\x0b\x32\x1a.apollo.control.FilterConf\x12\x41\n\x1creverse_station_leadlag_conf\x18\x0f \x01(\x0b\x32\x1b.apollo.control.LeadlagConf\x12?\n\x1areverse_speed_leadlag_conf\x18\x10 \x01(\x0b\x32\x1b.apollo.control.LeadlagConf\x12S\n\x11\x63\x61libration_table\x18\x11 \x01(\x0b\x32\x38.apollo.control.calibrationtable.ControlCalibrationTable\x12\x32\n#enable_reverse_leadlag_compensation\x18\x12 \x01(\x08:\x05\x66\x61lse\x12\x1e\n\x13switch_speed_window\x18\x13 \x01(\x01:\x01\x30'
  ,
  dependencies=[modules_dot_control_dot_proto_dot_calibration__table__pb2.DESCRIPTOR,modules_dot_control_dot_proto_dot_leadlag__conf__pb2.DESCRIPTOR,modules_dot_control_dot_proto_dot_pid__conf__pb2.DESCRIPTOR,])




_FILTERCONF = _descriptor.Descriptor(
  name='FilterConf',
  full_name='apollo.control.FilterConf',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cutoff_freq', full_name='apollo.control.FilterConf.cutoff_freq', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=194,
  serialized_end=227,
)


_LONCONTROLLERCONF = _descriptor.Descriptor(
  name='LonControllerConf',
  full_name='apollo.control.LonControllerConf',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ts', full_name='apollo.control.LonControllerConf.ts', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='brake_minimum_action', full_name='apollo.control.LonControllerConf.brake_minimum_action', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='throttle_minimum_action', full_name='apollo.control.LonControllerConf.throttle_minimum_action', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='speed_controller_input_limit', full_name='apollo.control.LonControllerConf.speed_controller_input_limit', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='station_error_limit', full_name='apollo.control.LonControllerConf.station_error_limit', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='preview_window', full_name='apollo.control.LonControllerConf.preview_window', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='standstill_acceleration', full_name='apollo.control.LonControllerConf.standstill_acceleration', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='station_pid_conf', full_name='apollo.control.LonControllerConf.station_pid_conf', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='low_speed_pid_conf', full_name='apollo.control.LonControllerConf.low_speed_pid_conf', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='high_speed_pid_conf', full_name='apollo.control.LonControllerConf.high_speed_pid_conf', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='switch_speed', full_name='apollo.control.LonControllerConf.switch_speed', index=10,
      number=11, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reverse_station_pid_conf', full_name='apollo.control.LonControllerConf.reverse_station_pid_conf', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reverse_speed_pid_conf', full_name='apollo.control.LonControllerConf.reverse_speed_pid_conf', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pitch_angle_filter_conf', full_name='apollo.control.LonControllerConf.pitch_angle_filter_conf', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reverse_station_leadlag_conf', full_name='apollo.control.LonControllerConf.reverse_station_leadlag_conf', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reverse_speed_leadlag_conf', full_name='apollo.control.LonControllerConf.reverse_speed_leadlag_conf', index=15,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='calibration_table', full_name='apollo.control.LonControllerConf.calibration_table', index=16,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_reverse_leadlag_compensation', full_name='apollo.control.LonControllerConf.enable_reverse_leadlag_compensation', index=17,
      number=18, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='switch_speed_window', full_name='apollo.control.LonControllerConf.switch_speed_window', index=18,
      number=19, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=230,
  serialized_end=1106,
)

_LONCONTROLLERCONF.fields_by_name['station_pid_conf'].message_type = modules_dot_control_dot_proto_dot_pid__conf__pb2._PIDCONF
_LONCONTROLLERCONF.fields_by_name['low_speed_pid_conf'].message_type = modules_dot_control_dot_proto_dot_pid__conf__pb2._PIDCONF
_LONCONTROLLERCONF.fields_by_name['high_speed_pid_conf'].message_type = modules_dot_control_dot_proto_dot_pid__conf__pb2._PIDCONF
_LONCONTROLLERCONF.fields_by_name['reverse_station_pid_conf'].message_type = modules_dot_control_dot_proto_dot_pid__conf__pb2._PIDCONF
_LONCONTROLLERCONF.fields_by_name['reverse_speed_pid_conf'].message_type = modules_dot_control_dot_proto_dot_pid__conf__pb2._PIDCONF
_LONCONTROLLERCONF.fields_by_name['pitch_angle_filter_conf'].message_type = _FILTERCONF
_LONCONTROLLERCONF.fields_by_name['reverse_station_leadlag_conf'].message_type = modules_dot_control_dot_proto_dot_leadlag__conf__pb2._LEADLAGCONF
_LONCONTROLLERCONF.fields_by_name['reverse_speed_leadlag_conf'].message_type = modules_dot_control_dot_proto_dot_leadlag__conf__pb2._LEADLAGCONF
_LONCONTROLLERCONF.fields_by_name['calibration_table'].message_type = modules_dot_control_dot_proto_dot_calibration__table__pb2._CONTROLCALIBRATIONTABLE
DESCRIPTOR.message_types_by_name['FilterConf'] = _FILTERCONF
DESCRIPTOR.message_types_by_name['LonControllerConf'] = _LONCONTROLLERCONF
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FilterConf = _reflection.GeneratedProtocolMessageType('FilterConf', (_message.Message,), {
  'DESCRIPTOR' : _FILTERCONF,
  '__module__' : 'modules.control.proto.lon_controller_conf_pb2'
  # @@protoc_insertion_point(class_scope:apollo.control.FilterConf)
  })
_sym_db.RegisterMessage(FilterConf)

LonControllerConf = _reflection.GeneratedProtocolMessageType('LonControllerConf', (_message.Message,), {
  'DESCRIPTOR' : _LONCONTROLLERCONF,
  '__module__' : 'modules.control.proto.lon_controller_conf_pb2'
  # @@protoc_insertion_point(class_scope:apollo.control.LonControllerConf)
  })
_sym_db.RegisterMessage(LonControllerConf)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/planning/proto/ipopt_return_status.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/planning/proto/ipopt_return_status.proto',
  package='apollo.planning',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n0modules/planning/proto/ipopt_return_status.proto\x12\x0f\x61pollo.planning*\xeb\x04\n\x11IpoptReturnStatus\x12\x13\n\x0fSOLVE_SUCCEEDED\x10\x00\x12\x1e\n\x1aSOLVED_TO_ACCEPTABLE_LEVEL\x10\x01\x12\x1f\n\x1bINFEASIBLE_PROBLEM_DETECTED\x10\x02\x12&\n\"SEARCH_DIRECTION_BECOMES_TOO_SMALL\x10\x03\x12\x15\n\x11\x44IVERGIN_ITERATES\x10\x04\x12\x17\n\x13USER_REQUESTED_STOP\x10\x05\x12\x18\n\x14\x46\x45\x41SIBLE_POINT_FOUND\x10\x06\x12(\n\x1bMAXIMUM_ITERATIONS_EXCEEDED\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12\x1f\n\x12RESTORATION_FAILED\x10\xfe\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12&\n\x19\x45RROR_IN_STEP_COMPUTATION\x10\xfd\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12*\n\x1dNOT_ENOUGH_DEGREES_OF_FREEDOM\x10\xf6\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12\'\n\x1aINVALID_PROGRAM_DEFINITION\x10\xf5\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12\x1b\n\x0eINVALID_OPTION\x10\xf4\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12$\n\x17INVALID_NUMBER_DETECTED\x10\xf3\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12$\n\x17UNRECOVERABLE_EXCEPTION\x10\x9c\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12&\n\x19NONIPOPT_EXCEPTION_THROWN\x10\x9b\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12 \n\x13INSUFFICIENT_MEMORY\x10\x9a\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12\x13\n\x0eINTERNAL_ERROR\x10\xc7\x01'
)

_IPOPTRETURNSTATUS = _descriptor.EnumDescriptor(
  name='IpoptReturnStatus',
  full_name='apollo.planning.IpoptReturnStatus',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SOLVE_SUCCEEDED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SOLVED_TO_ACCEPTABLE_LEVEL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INFEASIBLE_PROBLEM_DETECTED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SEARCH_DIRECTION_BECOMES_TOO_SMALL', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DIVERGIN_ITERATES', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='USER_REQUESTED_STOP', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FEASIBLE_POINT_FOUND', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MAXIMUM_ITERATIONS_EXCEEDED', index=7, number=-1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RESTORATION_FAILED', index=8, number=-2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ERROR_IN_STEP_COMPUTATION', index=9, number=-3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NOT_ENOUGH_DEGREES_OF_FREEDOM', index=10, number=-10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INVALID_PROGRAM_DEFINITION', index=11, number=-11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INVALID_OPTION', index=12, number=-12,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INVALID_NUMBER_DETECTED', index=13, number=-13,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNRECOVERABLE_EXCEPTION', index=14, number=-100,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NONIPOPT_EXCEPTION_THROWN', index=15, number=-101,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INSUFFICIENT_MEMORY', index=16, number=-102,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INTERNAL_ERROR', index=17, number=199,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=70,
  serialized_end=689,
)
_sym_db.RegisterEnumDescriptor(_IPOPTRETURNSTATUS)

IpoptReturnStatus = enum_type_wrapper.EnumTypeWrapper(_IPOPTRETURNSTATUS)
SOLVE_SUCCEEDED = 0
SOLVED_TO_ACCEPTABLE_LEVEL = 1
INFEASIBLE_PROBLEM_DETECTED = 2
SEARCH_DIRECTION_BECOMES_TOO_SMALL = 3
DIVERGIN_ITERATES = 4
USER_REQUESTED_STOP = 5
FEASIBLE_POINT_FOUND = 6
MAXIMUM_ITERATIONS_EXCEEDED = -1
RESTORATION_FAILED = -2
ERROR_IN_STEP_COMPUTATION = -3
NOT_ENOUGH_DEGREES_OF_FREEDOM = -10
INVALID_PROGRAM_DEFINITION = -11
INVALID_OPTION = -12
INVALID_NUMBER_DETECTED = -13
UNRECOVERABLE_EXCEPTION = -100
NONIPOPT_EXCEPTION_THROWN = -101
INSUFFICIENT_MEMORY = -102
INTERNAL_ERROR = 199


DESCRIPTOR.enum_types_by_name['IpoptReturnStatus'] = _IPOPTRETURNSTATUS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/prediction/proto/offline_features.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.common.proto import pnc_point_pb2 as modules_dot_common_dot_proto_dot_pnc__point__pb2
from modules.prediction.proto import feature_pb2 as modules_dot_prediction_dot_proto_dot_feature__pb2
from modules.prediction.proto import prediction_conf_pb2 as modules_dot_prediction_dot_proto_dot_prediction__conf__pb2
from modules.prediction.proto import scenario_pb2 as modules_dot_prediction_dot_proto_dot_scenario__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/prediction/proto/offline_features.proto',
  package='apollo.prediction',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n/modules/prediction/proto/offline_features.proto\x12\x11\x61pollo.prediction\x1a$modules/common/proto/pnc_point.proto\x1a&modules/prediction/proto/feature.proto\x1a.modules/prediction/proto/prediction_conf.proto\x1a\'modules/prediction/proto/scenario.proto\"\xb1\x01\n\x0f\x44\x61taForLearning\x12\x10\n\x08\x63\x61tegory\x18\x05 \x01(\t\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x11\n\ttimestamp\x18\x02 \x01(\x01\x12\x1d\n\x15\x66\x65\x61tures_for_learning\x18\x03 \x03(\x01\x12$\n\x1cstring_features_for_learning\x18\x07 \x03(\t\x12\x0e\n\x06labels\x18\x04 \x03(\x01\x12\x18\n\x10lane_sequence_id\x18\x06 \x01(\x05\"T\n\x13ListDataForLearning\x12=\n\x11\x64\x61ta_for_learning\x18\x01 \x03(\x0b\x32\".apollo.prediction.DataForLearning\"\xcb\x01\n\x10PredictionResult\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x11\n\ttimestamp\x18\x02 \x01(\x01\x12\x31\n\ntrajectory\x18\x03 \x03(\x0b\x32\x1d.apollo.prediction.Trajectory\x12\x36\n\robstacle_conf\x18\x04 \x01(\x0b\x32\x1f.apollo.prediction.ObstacleConf\x12-\n\x08scenario\x18\x05 \x01(\x0b\x32\x1b.apollo.prediction.Scenario\"V\n\x14ListPredictionResult\x12>\n\x11prediction_result\x18\x01 \x03(\x0b\x32#.apollo.prediction.PredictionResult\">\n\x0cListFrameEnv\x12.\n\tframe_env\x18\x01 \x03(\x0b\x32\x1b.apollo.prediction.FrameEnv\"\xcc\x01\n\rDataForTuning\x12\x10\n\x08\x63\x61tegory\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\x05\x12\x11\n\ttimestamp\x18\x03 \x01(\x01\x12\x19\n\x11values_for_tuning\x18\x04 \x03(\x01\x12\x17\n\x0freal_cost_value\x18\x05 \x03(\x01\x12\x18\n\x10lane_sequence_id\x18\x06 \x01(\x05\x12<\n\x14\x61\x64\x63_trajectory_point\x18\x07 \x03(\x0b\x32\x1e.apollo.common.TrajectoryPoint\"N\n\x11ListDataForTuning\x12\x39\n\x0f\x64\x61ta_for_tuning\x18\x01 \x03(\x0b\x32 .apollo.prediction.DataForTuning\"7\n\x08\x46\x65\x61tures\x12+\n\x07\x66\x65\x61ture\x18\x01 \x03(\x0b\x32\x1a.apollo.prediction.Feature'
  ,
  dependencies=[modules_dot_common_dot_proto_dot_pnc__point__pb2.DESCRIPTOR,modules_dot_prediction_dot_proto_dot_feature__pb2.DESCRIPTOR,modules_dot_prediction_dot_proto_dot_prediction__conf__pb2.DESCRIPTOR,modules_dot_prediction_dot_proto_dot_scenario__pb2.DESCRIPTOR,])




_DATAFORLEARNING = _descriptor.Descriptor(
  name='DataForLearning',
  full_name='apollo.prediction.DataForLearning',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='category', full_name='apollo.prediction.DataForLearning.category', index=0,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='apollo.prediction.DataForLearning.id', index=1,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='apollo.prediction.DataForLearning.timestamp', index=2,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='features_for_learning', full_name='apollo.prediction.DataForLearning.features_for_learning', index=3,
      number=3, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='string_features_for_learning', full_name='apollo.prediction.DataForLearning.string_features_for_learning', index=4,
      number=7, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='apollo.prediction.DataForLearning.labels', index=5,
      number=4, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane_sequence_id', full_name='apollo.prediction.DataForLearning.lane_sequence_id', index=6,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=238,
  serialized_end=415,
)


_LISTDATAFORLEARNING = _descriptor.Descriptor(
  name='ListDataForLearning',
  full_name='apollo.prediction.ListDataForLearning',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data_for_learning', full_name='apollo.prediction.ListDataForLearning.data_for_learning', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=417,
  serialized_end=501,
)


_PREDICTIONRESULT = _descriptor.Descriptor(
  name='PredictionResult',
  full_name='apollo.prediction.PredictionResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='apollo.prediction.PredictionResult.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='apollo.prediction.PredictionResult.timestamp', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trajectory', full_name='apollo.prediction.PredictionResult.trajectory', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='obstacle_conf', full_name='apollo.prediction.PredictionResult.obstacle_conf', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scenario', full_name='apollo.prediction.PredictionResult.scenario', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=504,
  serialized_end=707,
)


_LISTPREDICTIONRESULT = _descriptor.Descriptor(
  name='ListPredictionResult',
  full_name='apollo.prediction.ListPredictionResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='prediction_result', full_name='apollo.prediction.ListPredictionResult.prediction_result', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=709,
  serialized_end=795,
)


_LISTFRAMEENV = _descriptor.Descriptor(
  name='ListFrameEnv',
  full_name='apollo.prediction.ListFrameEnv',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='frame_env', full_name='apollo.prediction.ListFrameEnv.frame_env', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=797,
  serialized_end=859,
)


_DATAFORTUNING = _descriptor.Descriptor(
  name='DataForTuning',
  full_name='apollo.prediction.DataForTuning',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='category', full_name='apollo.prediction.DataForTuning.category', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='apollo.prediction.DataForTuning.id', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='apollo.prediction.DataForTuning.timestamp', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values_for_tuning', full_name='apollo.prediction.DataForTuning.values_for_tuning', index=3,
      number=4, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='real_cost_value', full_name='apollo.prediction.DataForTuning.real_cost_value', index=4,
      number=5, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane_sequence_id', full_name='apollo.prediction.DataForTuning.lane_sequence_id', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='adc_trajectory_point', full_name='apollo.prediction.DataForTuning.adc_trajectory_point', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=862,
  serialized_end=1066,
)


_LISTDATAFORTUNING = _descriptor.Descriptor(
  name='ListDataForTuning',
  full_name='apollo.prediction.ListDataForTuning',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data_for_tuning', full_name='apollo.prediction.ListDataForTuning.data_for_tuning', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1068,
  serialized_end=1146,
)


_FEATURES = _descriptor.Descriptor(
  name='Features',
  full_name='apollo.prediction.Features',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feature', full_name='apollo.prediction.Features.feature', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1148,
  serialized_end=1203,
)

_LISTDATAFORLEARNING.fields_by_name['data_for_learning'].message_type = _DATAFORLEARNING
_PREDICTIONRESULT.fields_by_name['trajectory'].message_type = modules_dot_prediction_dot_proto_dot_feature__pb2._TRAJECTORY
_PREDICTIONRESULT.fields_by_name['obstacle_conf'].message_type = modules_dot_prediction_dot_proto_dot_prediction__conf__pb2._OBSTACLECONF
_PREDICTIONRESULT.fields_by_name['scenario'].message_type = modules_dot_prediction_dot_proto_dot_scenario__pb2._SCENARIO
_LISTPREDICTIONRESULT.fields_by_name['prediction_result'].message_type = _PREDICTIONRESULT
_LISTFRAMEENV.fields_by_name['frame_env'].message_type = modules_dot_prediction_dot_proto_dot_feature__pb2._FRAMEENV
_DATAFORTUNING.fields_by_name['adc_trajectory_point'].message_type = modules_dot_common_dot_proto_dot_pnc__point__pb2._TRAJECTORYPOINT
_LISTDATAFORTUNING.fields_by_name['data_for_tuning'].message_type = _DATAFORTUNING
_FEATURES.fields_by_name['feature'].message_type = modules_dot_prediction_dot_proto_dot_feature__pb2._FEATURE
DESCRIPTOR.message_types_by_name['DataForLearning'] = _DATAFORLEARNING
DESCRIPTOR.message_types_by_name['ListDataForLearning'] = _LISTDATAFORLEARNING
DESCRIPTOR.message_types_by_name['PredictionResult'] = _PREDICTIONRESULT
DESCRIPTOR.message_types_by_name['ListPredictionResult'] = _LISTPREDICTIONRESULT
DESCRIPTOR.message_types_by_name['ListFrameEnv'] = _LISTFRAMEENV
DESCRIPTOR.message_types_by_name['DataForTuning'] = _DATAFORTUNING
DESCRIPTOR.message_types_by_name['ListDataForTuning'] = _LISTDATAFORTUNING
DESCRIPTOR.message_types_by_name['Features'] = _FEATURES
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DataForLearning = _reflection.GeneratedProtocolMessageType('DataForLearning', (_message.Message,), {
  'DESCRIPTOR' : _DATAFORLEARNING,
  '__module__' : 'modules.prediction.proto.offline_features_pb2'
  # @@protoc_insertion_point(class_scope:apollo.prediction.DataForLearning)
  })
_sym_db.RegisterMessage(DataForLearning)

ListDataForLearning = _reflection.GeneratedProtocolMessageType('ListDataForLearning', (_message.Message,), {
  'DESCRIPTOR' : _LISTDATAFORLEARNING,
  '__module__' : 'modules.prediction.proto.offline_features_pb2'
  # @@protoc_insertion_point(class_scope:apollo.prediction.ListDataForLearning)
  })
_sym_db.RegisterMessage(ListDataForLearning)

PredictionResult = _reflection.GeneratedProtocolMessageType('PredictionResult', (_message.Message,), {
  'DESCRIPTOR' : _PREDICTIONRESULT,
  '__module__' : 'modules.prediction.proto.offline_features_pb2'
  # @@protoc_insertion_point(class_scope:apollo.prediction.PredictionResult)
  })
_sym_db.RegisterMessage(PredictionResult)

ListPredictionResult = _reflection.GeneratedProtocolMessageType('ListPredictionResult', (_message.Message,), {
  'DESCRIPTOR' : _LISTPREDICTIONRESULT,
  '__module__' : 'modules.prediction.proto.offline_features_pb2'
  # @@protoc_insertion_point(class_scope:apollo.prediction.ListPredictionResult)
  })
_sym_db.RegisterMessage(ListPredictionResult)

ListFrameEnv = _reflection.GeneratedProtocolMessageType('ListFrameEnv', (_message.Message,), {
  'DESCRIPTOR' : _LISTFRAMEENV,
  '__module__' : 'modules.prediction.proto.offline_features_pb2'
  # @@protoc_insertion_point(class_scope:apollo.prediction.ListFrameEnv)
  })
_sym_db.RegisterMessage(ListFrameEnv)

DataForTuning = _reflection.GeneratedProtocolMessageType('DataForTuning', (_message.Message,), {
  'DESCRIPTOR' : _DATAFORTUNING,
  '__module__' : 'modules.prediction.proto.offline_features_pb2'
  # @@protoc_insertion_point(class_scope:apollo.prediction.DataForTuning)
  })
_sym_db.RegisterMessage(DataForTuning)

ListDataForTuning = _reflection.GeneratedProtocolMessageType('ListDataForTuning', (_message.Message,), {
  'DESCRIPTOR' : _LISTDATAFORTUNING,
  '__module__' : 'modules.prediction.proto.offline_features_pb2'
  # @@protoc_insertion_point(class_scope:apollo.prediction.ListDataForTuning)
  })
_sym_db.RegisterMessage(ListDataForTuning)

Features = _reflection.GeneratedProtocolMessageType('Features', (_message.Message,), {
  'DESCRIPTOR' : _FEATURES,
  '__module__' : 'modules.prediction.proto.offline_features_pb2'
  # @@protoc_insertion_point(class_scope:apollo.prediction.Features)
  })
_sym_db.RegisterMessage(Features)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/perception/proto/fused_classifier_config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/perception/proto/fused_classifier_config.proto',
  package='apollo.perception.lidar',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n6modules/perception/proto/fused_classifier_config.proto\x12\x17\x61pollo.perception.lidar\"\xec\x01\n\x15\x46usedClassifierConfig\x12\x1b\n\x0ftemporal_window\x18\x01 \x01(\x01:\x02\x32\x30\x12$\n\x16\x65nable_temporal_fusion\x18\x02 \x01(\x08:\x04true\x12\x35\n\x16one_shot_fusion_method\x18\x03 \x01(\t:\x15\x43\x43RFOneShotTypeFusion\x12\x36\n\x16sequence_fusion_method\x18\x04 \x01(\t:\x16\x43\x43RFSequenceTypeFusion\x12!\n\x13use_tracked_objects\x18\x05 \x01(\x08:\x04true'
)




_FUSEDCLASSIFIERCONFIG = _descriptor.Descriptor(
  name='FusedClassifierConfig',
  full_name='apollo.perception.lidar.FusedClassifierConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='temporal_window', full_name='apollo.perception.lidar.FusedClassifierConfig.temporal_window', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(20),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_temporal_fusion', full_name='apollo.perception.lidar.FusedClassifierConfig.enable_temporal_fusion', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='one_shot_fusion_method', full_name='apollo.perception.lidar.FusedClassifierConfig.one_shot_fusion_method', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"CCRFOneShotTypeFusion".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sequence_fusion_method', full_name='apollo.perception.lidar.FusedClassifierConfig.sequence_fusion_method', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=True, default_value=b"CCRFSequenceTypeFusion".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='use_tracked_objects', full_name='apollo.perception.lidar.FusedClassifierConfig.use_tracked_objects', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=84,
  serialized_end=320,
)

DESCRIPTOR.message_types_by_name['FusedClassifierConfig'] = _FUSEDCLASSIFIERCONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FusedClassifierConfig = _reflection.GeneratedProtocolMessageType('FusedClassifierConfig', (_message.Message,), {
  'DESCRIPTOR' : _FUSEDCLASSIFIERCONFIG,
  '__module__' : 'modules.perception.proto.fused_classifier_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.lidar.FusedClassifierConfig)
  })
_sym_db.RegisterMessage(FusedClassifierConfig)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/v2x/proto/v2x_monitor.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/v2x/proto/v2x_monitor.proto',
  package='apollo.v2x',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n#modules/v2x/proto/v2x_monitor.proto\x12\napollo.v2x\"Y\n\x08ObuAlarm\x12\x10\n\x08mode_num\x18\x01 \x02(\x01\x12(\n\terror_num\x18\x02 \x02(\x0e\x32\x15.apollo.v2x.ErrorCode\x12\x11\n\terror_msg\x18\x03 \x02(\t*_\n\tErrorCode\x12\t\n\x04LTEV\x10\xf4\x03\x12\x08\n\x03NET\x10\xf5\x03\x12\x08\n\x03\x43PU\x10\xf6\x03\x12\x08\n\x03MEM\x10\xf7\x03\x12\x08\n\x03GPS\x10\xf8\x03\x12\x08\n\x03MAP\x10\xfe\x03\x12\t\n\x04SPAT\x10\xff\x03\x12\n\n\x05OBUID\x10\xe7\x07'
)

_ERRORCODE = _descriptor.EnumDescriptor(
  name='ErrorCode',
  full_name='apollo.v2x.ErrorCode',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='LTEV', index=0, number=500,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NET', index=1, number=501,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CPU', index=2, number=502,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MEM', index=3, number=503,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GPS', index=4, number=504,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MAP', index=5, number=510,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SPAT', index=6, number=511,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OBUID', index=7, number=999,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=142,
  serialized_end=237,
)
_sym_db.RegisterEnumDescriptor(_ERRORCODE)

ErrorCode = enum_type_wrapper.EnumTypeWrapper(_ERRORCODE)
LTEV = 500
NET = 501
CPU = 502
MEM = 503
GPS = 504
MAP = 510
SPAT = 511
OBUID = 999



_OBUALARM = _descriptor.Descriptor(
  name='ObuAlarm',
  full_name='apollo.v2x.ObuAlarm',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='mode_num', full_name='apollo.v2x.ObuAlarm.mode_num', index=0,
      number=1, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error_num', full_name='apollo.v2x.ObuAlarm.error_num', index=1,
      number=2, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=500,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error_msg', full_name='apollo.v2x.ObuAlarm.error_msg', index=2,
      number=3, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=51,
  serialized_end=140,
)

_OBUALARM.fields_by_name['error_num'].enum_type = _ERRORCODE
DESCRIPTOR.message_types_by_name['ObuAlarm'] = _OBUALARM
DESCRIPTOR.enum_types_by_name['ErrorCode'] = _ERRORCODE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ObuAlarm = _reflection.GeneratedProtocolMessageType('ObuAlarm', (_message.Message,), {
  'DESCRIPTOR' : _OBUALARM,
  '__module__' : 'modules.v2x.proto.v2x_monitor_pb2'
  # @@protoc_insertion_point(class_scope:apollo.v2x.ObuAlarm)
  })
_sym_db.RegisterMessage(ObuAlarm)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/v2x/proto/v2x_traffic_light_policy.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/v2x/proto/v2x_traffic_light_policy.proto',
  package='apollo.v2x',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n0modules/v2x/proto/v2x_traffic_light_policy.proto\x12\napollo.v2x\"\"\n\nPosition2D\x12\t\n\x01x\x18\x01 \x01(\x01\x12\t\n\x01y\x18\x02 \x01(\x01\"\x92\x01\n\nConnection\x12;\n\x16\x61llow_driving_behavior\x18\x01 \x01(\x0e\x32\x1b.apollo.v2x.Connection.Type\x12\x10\n\x08phase_id\x18\x02 \x01(\x05\"5\n\x04Type\x12\x0c\n\x08STRAIGHT\x10\x00\x12\x08\n\x04LEFT\x10\x01\x12\t\n\x05RIGHT\x10\x02\x12\n\n\x06U_TURN\x10\x03\"u\n\x04Lane\x12\x0f\n\x07lane_id\x18\x01 \x01(\x05\x12/\n\x0fposition_offset\x18\x02 \x03(\x0b\x32\x16.apollo.v2x.Position2D\x12+\n\x0b\x63onnections\x18\x03 \x03(\x0b\x32\x16.apollo.v2x.Connection\"i\n\x04Road\x12\x18\n\x10upstream_node_id\x18\x01 \x01(\x05\x12&\n\x06points\x18\x02 \x01(\x0b\x32\x16.apollo.v2x.Position2D\x12\x1f\n\x05lanes\x18\x03 \x03(\x0b\x32\x10.apollo.v2x.Lane\"e\n\x0cIntersection\x12\n\n\x02id\x18\x01 \x01(\x05\x12(\n\x08position\x18\x02 \x01(\x0b\x32\x16.apollo.v2x.Position2D\x12\x1f\n\x05roads\x18\x03 \x03(\x0b\x32\x10.apollo.v2x.Road\"[\n\x03Map\x12\x12\n\ntime_stamp\x18\x01 \x01(\x01\x12\x0f\n\x07msg_cnt\x18\x02 \x01(\x05\x12/\n\rintersections\x18\x03 \x03(\x0b\x32\x18.apollo.v2x.Intersection\"\xad\x01\n\x05Phase\x12\n\n\x02id\x18\x01 \x01(\x05\x12&\n\x05\x63olor\x18\x02 \x01(\x0e\x32\x17.apollo.v2x.Phase.Color\x12\x1e\n\x16\x63olor_remaining_time_s\x18\x03 \x01(\x05\"P\n\x05\x43olor\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x07\n\x03RED\x10\x01\x12\n\n\x06YELLOW\x10\x02\x12\t\n\x05GREEN\x10\x03\x12\t\n\x05\x42LACK\x10\x04\x12\x0f\n\x0b\x46LASH_GREEN\x10\x05\"x\n\x11IntersectionState\x12\x17\n\x0fintersection_id\x18\x01 \x01(\x05\x12!\n\x06Phases\x18\x02 \x03(\x0b\x32\x11.apollo.v2x.Phase\x12\x0b\n\x03moy\x18\x03 \x01(\x05\x12\x1a\n\x12time_stamp_dsecond\x18\x04 \x01(\x05\"a\n\x04Spat\x12\x12\n\ntime_stamp\x18\x01 \x01(\x01\x12\x0f\n\x07msg_cnt\x18\x02 \x01(\x05\x12\x34\n\rintersections\x18\x03 \x03(\x0b\x32\x1d.apollo.v2x.IntersectionState\"J\n\nPolicyData\x12\x1c\n\x03map\x18\x01 \x01(\x0b\x32\x0f.apollo.v2x.Map\x12\x1e\n\x04spat\x18\x02 \x01(\x0b\x32\x10.apollo.v2x.Spat'
)



_CONNECTION_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='apollo.v2x.Connection.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STRAIGHT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LEFT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RIGHT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='U_TURN', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=194,
  serialized_end=247,
)
_sym_db.RegisterEnumDescriptor(_CONNECTION_TYPE)

_PHASE_COLOR = _descriptor.EnumDescriptor(
  name='Color',
  full_name='apollo.v2x.Phase.Color',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='YELLOW', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GREEN', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BLACK', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FLASH_GREEN', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=765,
  serialized_end=845,
)
_sym_db.RegisterEnumDescriptor(_PHASE_COLOR)


_POSITION2D = _descriptor.Descriptor(
  name='Position2D',
  full_name='apollo.v2x.Position2D',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='apollo.v2x.Position2D.x', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='y', full_name='apollo.v2x.Position2D.y', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=64,
  serialized_end=98,
)


_CONNECTION = _descriptor.Descriptor(
  name='Connection',
  full_name='apollo.v2x.Connection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='allow_driving_behavior', full_name='apollo.v2x.Connection.allow_driving_behavior', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='phase_id', full_name='apollo.v2x.Connection.phase_id', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CONNECTION_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=101,
  serialized_end=247,
)


_LANE = _descriptor.Descriptor(
  name='Lane',
  full_name='apollo.v2x.Lane',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='lane_id', full_name='apollo.v2x.Lane.lane_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='position_offset', full_name='apollo.v2x.Lane.position_offset', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connections', full_name='apollo.v2x.Lane.connections', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=249,
  serialized_end=366,
)


_ROAD = _descriptor.Descriptor(
  name='Road',
  full_name='apollo.v2x.Road',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='upstream_node_id', full_name='apollo.v2x.Road.upstream_node_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='points', full_name='apollo.v2x.Road.points', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lanes', full_name='apollo.v2x.Road.lanes', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=368,
  serialized_end=473,
)


_INTERSECTION = _descriptor.Descriptor(
  name='Intersection',
  full_name='apollo.v2x.Intersection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='apollo.v2x.Intersection.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='position', full_name='apollo.v2x.Intersection.position', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='roads', full_name='apollo.v2x.Intersection.roads', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=475,
  serialized_end=576,
)


_MAP = _descriptor.Descriptor(
  name='Map',
  full_name='apollo.v2x.Map',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='time_stamp', full_name='apollo.v2x.Map.time_stamp', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='msg_cnt', full_name='apollo.v2x.Map.msg_cnt', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='intersections', full_name='apollo.v2x.Map.intersections', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=578,
  serialized_end=669,
)


_PHASE = _descriptor.Descriptor(
  name='Phase',
  full_name='apollo.v2x.Phase',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='apollo.v2x.Phase.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='color', full_name='apollo.v2x.Phase.color', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='color_remaining_time_s', full_name='apollo.v2x.Phase.color_remaining_time_s', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PHASE_COLOR,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=672,
  serialized_end=845,
)


_INTERSECTIONSTATE = _descriptor.Descriptor(
  name='IntersectionState',
  full_name='apollo.v2x.IntersectionState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='intersection_id', full_name='apollo.v2x.IntersectionState.intersection_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Phases', full_name='apollo.v2x.IntersectionState.Phases', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='moy', full_name='apollo.v2x.IntersectionState.moy', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_stamp_dsecond', full_name='apollo.v2x.IntersectionState.time_stamp_dsecond', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=847,
  serialized_end=967,
)


_SPAT = _descriptor.Descriptor(
  name='Spat',
  full_name='apollo.v2x.Spat',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='time_stamp', full_name='apollo.v2x.Spat.time_stamp', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='msg_cnt', full_name='apollo.v2x.Spat.msg_cnt', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='intersections', full_name='apollo.v2x.Spat.intersections', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=969,
  serialized_end=1066,
)


_POLICYDATA = _descriptor.Descriptor(
  name='PolicyData',
  full_name='apollo.v2x.PolicyData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='map', full_name='apollo.v2x.PolicyData.map', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='spat', full_name='apollo.v2x.PolicyData.spat', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1068,
  serialized_end=1142,
)

_CONNECTION.fields_by_name['allow_driving_behavior'].enum_type = _CONNECTION_TYPE
_CONNECTION_TYPE.containing_type = _CONNECTION
_LANE.fields_by_name['position_offset'].message_type = _POSITION2D
_LANE.fields_by_name['connections'].message_type = _CONNECTION
_ROAD.fields_by_name['points'].message_type = _POSITION2D
_ROAD.fields_by_name['lanes'].message_type = _LANE
_INTERSECTION.fields_by_name['position'].message_type = _POSITION2D
_INTERSECTION.fields_by_name['roads'].message_type = _ROAD
_MAP.fields_by_name['intersections'].message_type = _INTERSECTION
_PHASE.fields_by_name['color'].enum_type = _PHASE_COLOR
_PHASE_COLOR.containing_type = _PHASE
_INTERSECTIONSTATE.fields_by_name['Phases'].message_type = _PHASE
_SPAT.fields_by_name['intersections'].message_type = _INTERSECTIONSTATE
_POLICYDATA.fields_by_name['map'].message_type = _MAP
_POLICYDATA.fields_by_name['spat'].message_type = _SPAT
DESCRIPTOR.message_types_by_name['Position2D'] = _POSITION2D
DESCRIPTOR.message_types_by_name['Connection'] = _CONNECTION
DESCRIPTOR.message_types_by_name['Lane'] = _LANE
DESCRIPTOR.message_types_by_name['Road'] = _ROAD
DESCRIPTOR.message_types_by_name['Intersection'] = _INTERSECTION
DESCRIPTOR.message_types_by_name['Map'] = _MAP
DESCRIPTOR.message_types_by_name['Phase'] = _PHASE
DESCRIPTOR.message_types_by_name['IntersectionState'] = _INTERSECTIONSTATE
DESCRIPTOR.message_types_by_name['Spat'] = _SPAT
DESCRIPTOR.message_types_by_name['PolicyData'] = _POLICYDATA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Position2D = _reflection.GeneratedProtocolMessageType('Position2D', (_message.Message,), {
  'DESCRIPTOR' : _POSITION2D,
  '__module__' : 'modules.v2x.proto.v2x_traffic_light_policy_pb2'
  # @@protoc_insertion_point(class_scope:apollo.v2x.Position2D)
  })
_sym_db.RegisterMessage(Position2D)

Connection = _reflection.GeneratedProtocolMessageType('Connection', (_message.Message,), {
  'DESCRIPTOR' : _CONNECTION,
  '__module__' : 'modules.v2x.proto.v2x_traffic_light_policy_pb2'
  # @@protoc_insertion_point(class_scope:apollo.v2x.Connection)
  })
_sym_db.RegisterMessage(Connection)

Lane = _reflection.GeneratedProtocolMessageType('Lane', (_message.Message,), {
  'DESCRIPTOR' : _LANE,
  '__module__' : 'modules.v2x.proto.v2x_traffic_light_policy_pb2'
  # @@protoc_insertion_point(class_scope:apollo.v2x.Lane)
  })
_sym_db.RegisterMessage(Lane)

Road = _reflection.GeneratedProtocolMessageType('Road', (_message.Message,), {
  'DESCRIPTOR' : _ROAD,
  '__module__' : 'modules.v2x.proto.v2x_traffic_light_policy_pb2'
  # @@protoc_insertion_point(class_scope:apollo.v2x.Road)
  })
_sym_db.RegisterMessage(Road)

Intersection = _reflection.GeneratedProtocolMessageType('Intersection', (_message.Message,), {
  'DESCRIPTOR' : _INTERSECTION,
  '__module__' : 'modules.v2x.proto.v2x_traffic_light_policy_pb2'
  # @@protoc_insertion_point(class_scope:apollo.v2x.Intersection)
  })
_sym_db.RegisterMessage(Intersection)

Map = _reflection.GeneratedProtocolMessageType('Map', (_message.Message,), {
  'DESCRIPTOR' : _MAP,
  '__module__' : 'modules.v2x.proto.v2x_traffic_light_policy_pb2'
  # @@protoc_insertion_point(class_scope:apollo.v2x.Map)
  })
_sym_db.RegisterMessage(Map)

Phase = _reflection.GeneratedProtocolMessageType('Phase', (_message.Message,), {
  'DESCRIPTOR' : _PHASE,
  '__module__' : 'modules.v2x.proto.v2x_traffic_light_policy_pb2'
  # @@protoc_insertion_point(class_scope:apollo.v2x.Phase)
  })
_sym_db.RegisterMessage(Phase)

IntersectionState = _reflection.GeneratedProtocolMessageType('IntersectionState', (_message.Message,), {
  'DESCRIPTOR' : _INTERSECTIONSTATE,
  '__module__' : 'modules.v2x.proto.v2x_traffic_light_policy_pb2'
  # @@protoc_insertion_point(class_scope:apollo.v2x.IntersectionState)
  })
_sym_db.RegisterMessage(IntersectionState)

Spat = _reflection.GeneratedProtocolMessageType('Spat', (_message.Message,), {
  'DESCRIPTOR' : _SPAT,
  '__module__' : 'modules.v2x.proto.v2x_traffic_light_policy_pb2'
  # @@protoc_insertion_point(class_scope:apollo.v2x.Spat)
  })
_sym_db.RegisterMessage(Spat)

PolicyData = _reflection.GeneratedProtocolMessageType('PolicyData', (_message.Message,), {
  'DESCRIPTOR' : _POLICYDATA,
  '__module__' : 'modules.v2x.proto.v2x_traffic_light_policy_pb2'
  # @@protoc_insertion_point(class_scope:apollo.v2x.PolicyData)
  })
_sym_db.RegisterMessage(PolicyData)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/dreamview/backend/teleop/proto/modem_info.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.common.proto import header_pb2 as modules_dot_common_dot_proto_dot_header__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/dreamview/backend/teleop/proto/modem_info.proto',
  package='modules.teleop.modem',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n7modules/dreamview/backend/teleop/proto/modem_info.proto\x12\x14modules.teleop.modem\x1a!modules/common/proto/header.proto\"\xde\x02\n\tModemInfo\x12%\n\x06header\x18\x01 \x01(\x0b\x32\x15.apollo.common.Header\x12\x10\n\x08provider\x18\x02 \x01(\t\x12\n\n\x02ip\x18\x03 \x01(\t\x12\x10\n\x08ip_count\x18\x04 \x01(\x05\x12\x0f\n\x07gateway\x18\x05 \x01(\t\x12\x0c\n\x04port\x18\x06 \x01(\t\x12\x0b\n\x03\x64\x65v\x18\x07 \x01(\t\x12\n\n\x02tx\x18\x08 \x01(\x04\x12\n\n\x02rx\x18\t \x01(\x04\x12\x0c\n\x04ping\x18\n \x01(\t\x12\r\n\x05smoni\x18\x0b \x01(\t\x12\x12\n\ntechnology\x18\x0c \x01(\t\x12\x12\n\nconnection\x18\r \x01(\t\x12\x0e\n\x06signal\x18\x0e \x01(\x05\x12\x0f\n\x07quality\x18\x0f \x01(\x05\x12\x14\n\x0c\x62\x61ndwidth_ul\x18\x10 \x01(\x05\x12\x14\n\x0c\x62\x61ndwidth_dl\x18\x11 \x01(\x05\x12\x16\n\x0e\x63\x61_aggregation\x18\x12 \x01(\x08\x12\x0c\n\x04rank\x18\x13 \x01(\x05'
  ,
  dependencies=[modules_dot_common_dot_proto_dot_header__pb2.DESCRIPTOR,])




_MODEMINFO = _descriptor.Descriptor(
  name='ModemInfo',
  full_name='modules.teleop.modem.ModemInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='modules.teleop.modem.ModemInfo.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='provider', full_name='modules.teleop.modem.ModemInfo.provider', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ip', full_name='modules.teleop.modem.ModemInfo.ip', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ip_count', full_name='modules.teleop.modem.ModemInfo.ip_count', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gateway', full_name='modules.teleop.modem.ModemInfo.gateway', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='port', full_name='modules.teleop.modem.ModemInfo.port', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dev', full_name='modules.teleop.modem.ModemInfo.dev', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tx', full_name='modules.teleop.modem.ModemInfo.tx', index=7,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rx', full_name='modules.teleop.modem.ModemInfo.rx', index=8,
      number=9, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ping', full_name='modules.teleop.modem.ModemInfo.ping', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='smoni', full_name='modules.teleop.modem.ModemInfo.smoni', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='technology', full_name='modules.teleop.modem.ModemInfo.technology', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connection', full_name='modules.teleop.modem.ModemInfo.connection', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signal', full_name='modules.teleop.modem.ModemInfo.signal', index=13,
      number=14, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quality', full_name='modules.teleop.modem.ModemInfo.quality', index=14,
      number=15, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bandwidth_ul', full_name='modules.teleop.modem.ModemInfo.bandwidth_ul', index=15,
      number=16, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bandwidth_dl', full_name='modules.teleop.modem.ModemInfo.bandwidth_dl', index=16,
      number=17, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ca_aggregation', full_name='modules.teleop.modem.ModemInfo.ca_aggregation', index=17,
      number=18, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rank', full_name='modules.teleop.modem.ModemInfo.rank', index=18,
      number=19, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=117,
  serialized_end=467,
)

_MODEMINFO.fields_by_name['header'].message_type = modules_dot_common_dot_proto_dot_header__pb2._HEADER
DESCRIPTOR.message_types_by_name['ModemInfo'] = _MODEMINFO
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ModemInfo = _reflection.GeneratedProtocolMessageType('ModemInfo', (_message.Message,), {
  'DESCRIPTOR' : _MODEMINFO,
  '__module__' : 'modules.dreamview.backend.teleop.proto.modem_info_pb2'
  # @@protoc_insertion_point(class_scope:modules.teleop.modem.ModemInfo)
  })
_sym_db.RegisterMessage(ModemInfo)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/drivers/lidar/proto/robosense.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.common.proto import header_pb2 as modules_dot_common_dot_proto_dot_header__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/drivers/lidar/proto/robosense.proto',
  package='apollo.drivers.robosense',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n+modules/drivers/lidar/proto/robosense.proto\x12\x18\x61pollo.drivers.robosense\x1a!modules/common/proto/header.proto\"2\n\x13RobosenseScanPacket\x12\r\n\x05stamp\x18\x01 \x01(\x04\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\"\x9e\x01\n\rRobosenseScan\x12%\n\x06header\x18\x01 \x01(\x0b\x32\x15.apollo.common.Header\x12\r\n\x05model\x18\x02 \x01(\t\x12\x42\n\x0b\x66iring_pkts\x18\x03 \x03(\x0b\x32-.apollo.drivers.robosense.RobosenseScanPacket\x12\x13\n\x08\x62\x61setime\x18\x04 \x01(\x04:\x01\x30'
  ,
  dependencies=[modules_dot_common_dot_proto_dot_header__pb2.DESCRIPTOR,])




_ROBOSENSESCANPACKET = _descriptor.Descriptor(
  name='RobosenseScanPacket',
  full_name='apollo.drivers.robosense.RobosenseScanPacket',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='stamp', full_name='apollo.drivers.robosense.RobosenseScanPacket.stamp', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='apollo.drivers.robosense.RobosenseScanPacket.data', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=108,
  serialized_end=158,
)


_ROBOSENSESCAN = _descriptor.Descriptor(
  name='RobosenseScan',
  full_name='apollo.drivers.robosense.RobosenseScan',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='apollo.drivers.robosense.RobosenseScan.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='model', full_name='apollo.drivers.robosense.RobosenseScan.model', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='firing_pkts', full_name='apollo.drivers.robosense.RobosenseScan.firing_pkts', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='basetime', full_name='apollo.drivers.robosense.RobosenseScan.basetime', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=161,
  serialized_end=319,
)

_ROBOSENSESCAN.fields_by_name['header'].message_type = modules_dot_common_dot_proto_dot_header__pb2._HEADER
_ROBOSENSESCAN.fields_by_name['firing_pkts'].message_type = _ROBOSENSESCANPACKET
DESCRIPTOR.message_types_by_name['RobosenseScanPacket'] = _ROBOSENSESCANPACKET
DESCRIPTOR.message_types_by_name['RobosenseScan'] = _ROBOSENSESCAN
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RobosenseScanPacket = _reflection.GeneratedProtocolMessageType('RobosenseScanPacket', (_message.Message,), {
  'DESCRIPTOR' : _ROBOSENSESCANPACKET,
  '__module__' : 'modules.drivers.lidar.proto.robosense_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.robosense.RobosenseScanPacket)
  })
_sym_db.RegisterMessage(RobosenseScanPacket)

RobosenseScan = _reflection.GeneratedProtocolMessageType('RobosenseScan', (_message.Message,), {
  'DESCRIPTOR' : _ROBOSENSESCAN,
  '__module__' : 'modules.drivers.lidar.proto.robosense_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.robosense.RobosenseScan)
  })
_sym_db.RegisterMessage(RobosenseScan)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/localization/proto/sins_pva.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.common.proto import header_pb2 as modules_dot_common_dot_proto_dot_header__pb2
from modules.common.proto import geometry_pb2 as modules_dot_common_dot_proto_dot_geometry__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/localization/proto/sins_pva.proto',
  package='apollo.localization',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n)modules/localization/proto/sins_pva.proto\x12\x13\x61pollo.localization\x1a!modules/common/proto/header.proto\x1a#modules/common/proto/geometry.proto\"\xe7\x01\n\x0cIntegSinsPva\x12%\n\x06header\x18\x01 \x01(\x0b\x32\x15.apollo.common.Header\x12)\n\x08position\x18\x02 \x01(\x0b\x32\x17.apollo.common.PointLLH\x12(\n\x08velocity\x18\x03 \x01(\x0b\x32\x16.apollo.common.Point3D\x12(\n\x08\x61ttitude\x18\x04 \x01(\x0b\x32\x16.apollo.common.Point3D\x12\x15\n\tpva_covar\x18\x05 \x03(\x01\x42\x02\x10\x01\x12\x1a\n\x12init_and_alignment\x18\x06 \x01(\x08'
  ,
  dependencies=[modules_dot_common_dot_proto_dot_header__pb2.DESCRIPTOR,modules_dot_common_dot_proto_dot_geometry__pb2.DESCRIPTOR,])




_INTEGSINSPVA = _descriptor.Descriptor(
  name='IntegSinsPva',
  full_name='apollo.localization.IntegSinsPva',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='apollo.localization.IntegSinsPva.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='position', full_name='apollo.localization.IntegSinsPva.position', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='velocity', full_name='apollo.localization.IntegSinsPva.velocity', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attitude', full_name='apollo.localization.IntegSinsPva.attitude', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pva_covar', full_name='apollo.localization.IntegSinsPva.pva_covar', index=4,
      number=5, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='init_and_alignment', full_name='apollo.localization.IntegSinsPva.init_and_alignment', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=139,
  serialized_end=370,
)

_INTEGSINSPVA.fields_by_name['header'].message_type = modules_dot_common_dot_proto_dot_header__pb2._HEADER
_INTEGSINSPVA.fields_by_name['position'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINTLLH
_INTEGSINSPVA.fields_by_name['velocity'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINT3D
_INTEGSINSPVA.fields_by_name['attitude'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINT3D
DESCRIPTOR.message_types_by_name['IntegSinsPva'] = _INTEGSINSPVA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

IntegSinsPva = _reflection.GeneratedProtocolMessageType('IntegSinsPva', (_message.Message,), {
  'DESCRIPTOR' : _INTEGSINSPVA,
  '__module__' : 'modules.localization.proto.sins_pva_pb2'
  # @@protoc_insertion_point(class_scope:apollo.localization.IntegSinsPva)
  })
_sym_db.RegisterMessage(IntegSinsPva)


_INTEGSINSPVA.fields_by_name['pva_covar']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/drivers/proto/conti_radar.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.common.proto import header_pb2 as modules_dot_common_dot_proto_dot_header__pb2
from modules.drivers.radar.conti_radar.proto import conti_radar_conf_pb2 as modules_dot_drivers_dot_radar_dot_conti__radar_dot_proto_dot_conti__radar__conf__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/drivers/proto/conti_radar.proto',
  package='apollo.drivers',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\'modules/drivers/proto/conti_radar.proto\x12\x0e\x61pollo.drivers\x1a!modules/common/proto/header.proto\x1a>modules/drivers/radar/conti_radar/proto/conti_radar_conf.proto\"m\n\x15\x43lusterListStatus_600\x12\x0f\n\x04near\x18\x01 \x01(\x05:\x01\x30\x12\x0e\n\x03\x66\x61r\x18\x02 \x01(\x05:\x01\x30\x12\x18\n\x0cmeas_counter\x18\x03 \x01(\x05:\x02-1\x12\x19\n\x11interface_version\x18\x04 \x01(\x05\"c\n\x14ObjectListStatus_60A\x12\x16\n\x0bnof_objects\x18\x01 \x01(\x05:\x01\x30\x12\x18\n\x0cmeas_counter\x18\x02 \x01(\x05:\x02-1\x12\x19\n\x11interface_version\x18\x03 \x01(\x05\"\xe6\x01\n\x0eRadarState_201\x12\x14\n\x0cmax_distance\x18\x01 \x01(\r\x12\x13\n\x0bradar_power\x18\x02 \x01(\r\x12;\n\x0boutput_type\x18\x03 \x01(\x0e\x32&.apollo.drivers.conti_radar.OutputType\x12?\n\rrcs_threshold\x18\x04 \x01(\x0e\x32(.apollo.drivers.conti_radar.RcsThreshold\x12\x14\n\x0csend_quality\x18\x05 \x01(\x08\x12\x15\n\rsend_ext_info\x18\x06 \x01(\x08\"\xc1\x04\n\rContiRadarObs\x12%\n\x06header\x18\x01 \x01(\x0b\x32\x15.apollo.common.Header\x12\x16\n\x0e\x63lusterortrack\x18\x02 \x01(\x08\x12\x13\n\x0bobstacle_id\x18\x03 \x01(\x05\x12\x16\n\x0elongitude_dist\x18\x04 \x01(\x01\x12\x14\n\x0clateral_dist\x18\x05 \x01(\x01\x12\x15\n\rlongitude_vel\x18\x06 \x01(\x01\x12\x13\n\x0blateral_vel\x18\x07 \x01(\x01\x12\x0b\n\x03rcs\x18\x08 \x01(\x01\x12\x0f\n\x07\x64ynprop\x18\t \x01(\x05\x12\x1a\n\x12longitude_dist_rms\x18\n \x01(\x01\x12\x18\n\x10lateral_dist_rms\x18\x0b \x01(\x01\x12\x19\n\x11longitude_vel_rms\x18\x0c \x01(\x01\x12\x17\n\x0flateral_vel_rms\x18\r \x01(\x01\x12\x11\n\tprobexist\x18\x0e \x01(\x01\x12\x12\n\nmeas_state\x18\x0f \x01(\x05\x12\x17\n\x0flongitude_accel\x18\x10 \x01(\x01\x12\x15\n\rlateral_accel\x18\x11 \x01(\x01\x12\x17\n\x0foritation_angle\x18\x12 \x01(\x01\x12\x1b\n\x13longitude_accel_rms\x18\x13 \x01(\x01\x12\x19\n\x11lateral_accel_rms\x18\x14 \x01(\x01\x12\x1b\n\x13oritation_angle_rms\x18\x15 \x01(\x01\x12\x0e\n\x06length\x18\x16 \x01(\x01\x12\r\n\x05width\x18\x17 \x01(\x01\x12\x16\n\x0eobstacle_class\x18\x18 \x01(\x05\"\x9f\x02\n\nContiRadar\x12%\n\x06header\x18\x01 \x01(\x0b\x32\x15.apollo.common.Header\x12/\n\x08\x63ontiobs\x18\x02 \x03(\x0b\x32\x1d.apollo.drivers.ContiRadarObs\x12\x33\n\x0bradar_state\x18\x03 \x01(\x0b\x32\x1e.apollo.drivers.RadarState_201\x12\x42\n\x13\x63luster_list_status\x18\x04 \x01(\x0b\x32%.apollo.drivers.ClusterListStatus_600\x12@\n\x12object_list_status\x18\x05 \x01(\x0b\x32$.apollo.drivers.ObjectListStatus_60A'
  ,
  dependencies=[modules_dot_common_dot_proto_dot_header__pb2.DESCRIPTOR,modules_dot_drivers_dot_radar_dot_conti__radar_dot_proto_dot_conti__radar__conf__pb2.DESCRIPTOR,])




_CLUSTERLISTSTATUS_600 = _descriptor.Descriptor(
  name='ClusterListStatus_600',
  full_name='apollo.drivers.ClusterListStatus_600',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='near', full_name='apollo.drivers.ClusterListStatus_600.near', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='far', full_name='apollo.drivers.ClusterListStatus_600.far', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='meas_counter', full_name='apollo.drivers.ClusterListStatus_600.meas_counter', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=-1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='interface_version', full_name='apollo.drivers.ClusterListStatus_600.interface_version', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=158,
  serialized_end=267,
)


_OBJECTLISTSTATUS_60A = _descriptor.Descriptor(
  name='ObjectListStatus_60A',
  full_name='apollo.drivers.ObjectListStatus_60A',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='nof_objects', full_name='apollo.drivers.ObjectListStatus_60A.nof_objects', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='meas_counter', full_name='apollo.drivers.ObjectListStatus_60A.meas_counter', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=-1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='interface_version', full_name='apollo.drivers.ObjectListStatus_60A.interface_version', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=269,
  serialized_end=368,
)


_RADARSTATE_201 = _descriptor.Descriptor(
  name='RadarState_201',
  full_name='apollo.drivers.RadarState_201',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='max_distance', full_name='apollo.drivers.RadarState_201.max_distance', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='radar_power', full_name='apollo.drivers.RadarState_201.radar_power', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='output_type', full_name='apollo.drivers.RadarState_201.output_type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rcs_threshold', full_name='apollo.drivers.RadarState_201.rcs_threshold', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='send_quality', full_name='apollo.drivers.RadarState_201.send_quality', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='send_ext_info', full_name='apollo.drivers.RadarState_201.send_ext_info', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=371,
  serialized_end=601,
)


_CONTIRADAROBS = _descriptor.Descriptor(
  name='ContiRadarObs',
  full_name='apollo.drivers.ContiRadarObs',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='apollo.drivers.ContiRadarObs.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clusterortrack', full_name='apollo.drivers.ContiRadarObs.clusterortrack', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='obstacle_id', full_name='apollo.drivers.ContiRadarObs.obstacle_id', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='longitude_dist', full_name='apollo.drivers.ContiRadarObs.longitude_dist', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lateral_dist', full_name='apollo.drivers.ContiRadarObs.lateral_dist', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='longitude_vel', full_name='apollo.drivers.ContiRadarObs.longitude_vel', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lateral_vel', full_name='apollo.drivers.ContiRadarObs.lateral_vel', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rcs', full_name='apollo.drivers.ContiRadarObs.rcs', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dynprop', full_name='apollo.drivers.ContiRadarObs.dynprop', index=8,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='longitude_dist_rms', full_name='apollo.drivers.ContiRadarObs.longitude_dist_rms', index=9,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lateral_dist_rms', full_name='apollo.drivers.ContiRadarObs.lateral_dist_rms', index=10,
      number=11, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='longitude_vel_rms', full_name='apollo.drivers.ContiRadarObs.longitude_vel_rms', index=11,
      number=12, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lateral_vel_rms', full_name='apollo.drivers.ContiRadarObs.lateral_vel_rms', index=12,
      number=13, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='probexist', full_name='apollo.drivers.ContiRadarObs.probexist', index=13,
      number=14, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='meas_state', full_name='apollo.drivers.ContiRadarObs.meas_state', index=14,
      number=15, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='longitude_accel', full_name='apollo.drivers.ContiRadarObs.longitude_accel', index=15,
      number=16, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lateral_accel', full_name='apollo.drivers.ContiRadarObs.lateral_accel', index=16,
      number=17, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oritation_angle', full_name='apollo.drivers.ContiRadarObs.oritation_angle', index=17,
      number=18, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='longitude_accel_rms', full_name='apollo.drivers.ContiRadarObs.longitude_accel_rms', index=18,
      number=19, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lateral_accel_rms', full_name='apollo.drivers.ContiRadarObs.lateral_accel_rms', index=19,
      number=20, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oritation_angle_rms', full_name='apollo.drivers.ContiRadarObs.oritation_angle_rms', index=20,
      number=21, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='length', full_name='apollo.drivers.ContiRadarObs.length', index=21,
      number=22, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='width', full_name='apollo.drivers.ContiRadarObs.width', index=22,
      number=23, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='obstacle_class', full_name='apollo.drivers.ContiRadarObs.obstacle_class', index=23,
      number=24, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=604,
  serialized_end=1181,
)


_CONTIRADAR = _descriptor.Descriptor(
  name='ContiRadar',
  full_name='apollo.drivers.ContiRadar',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='apollo.drivers.ContiRadar.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='contiobs', full_name='apollo.drivers.ContiRadar.contiobs', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='radar_state', full_name='apollo.drivers.ContiRadar.radar_state', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cluster_list_status', full_name='apollo.drivers.ContiRadar.cluster_list_status', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='object_list_status', full_name='apollo.drivers.ContiRadar.object_list_status', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1184,
  serialized_end=1471,
)

_RADARSTATE_201.fields_by_name['output_type'].enum_type = modules_dot_drivers_dot_radar_dot_conti__radar_dot_proto_dot_conti__radar__conf__pb2._OUTPUTTYPE
_RADARSTATE_201.fields_by_name['rcs_threshold'].enum_type = modules_dot_drivers_dot_radar_dot_conti__radar_dot_proto_dot_conti__radar__conf__pb2._RCSTHRESHOLD
_CONTIRADAROBS.fields_by_name['header'].message_type = modules_dot_common_dot_proto_dot_header__pb2._HEADER
_CONTIRADAR.fields_by_name['header'].message_type = modules_dot_common_dot_proto_dot_header__pb2._HEADER
_CONTIRADAR.fields_by_name['contiobs'].message_type = _CONTIRADAROBS
_CONTIRADAR.fields_by_name['radar_state'].message_type = _RADARSTATE_201
_CONTIRADAR.fields_by_name['cluster_list_status'].message_type = _CLUSTERLISTSTATUS_600
_CONTIRADAR.fields_by_name['object_list_status'].message_type = _OBJECTLISTSTATUS_60A
DESCRIPTOR.message_types_by_name['ClusterListStatus_600'] = _CLUSTERLISTSTATUS_600
DESCRIPTOR.message_types_by_name['ObjectListStatus_60A'] = _OBJECTLISTSTATUS_60A
DESCRIPTOR.message_types_by_name['RadarState_201'] = _RADARSTATE_201
DESCRIPTOR.message_types_by_name['ContiRadarObs'] = _CONTIRADAROBS
DESCRIPTOR.message_types_by_name['ContiRadar'] = _CONTIRADAR
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ClusterListStatus_600 = _reflection.GeneratedProtocolMessageType('ClusterListStatus_600', (_message.Message,), {
  'DESCRIPTOR' : _CLUSTERLISTSTATUS_600,
  '__module__' : 'modules.drivers.proto.conti_radar_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.ClusterListStatus_600)
  })
_sym_db.RegisterMessage(ClusterListStatus_600)

ObjectListStatus_60A = _reflection.GeneratedProtocolMessageType('ObjectListStatus_60A', (_message.Message,), {
  'DESCRIPTOR' : _OBJECTLISTSTATUS_60A,
  '__module__' : 'modules.drivers.proto.conti_radar_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.ObjectListStatus_60A)
  })
_sym_db.RegisterMessage(ObjectListStatus_60A)

RadarState_201 = _reflection.GeneratedProtocolMessageType('RadarState_201', (_message.Message,), {
  'DESCRIPTOR' : _RADARSTATE_201,
  '__module__' : 'modules.drivers.proto.conti_radar_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.RadarState_201)
  })
_sym_db.RegisterMessage(RadarState_201)

ContiRadarObs = _reflection.GeneratedProtocolMessageType('ContiRadarObs', (_message.Message,), {
  'DESCRIPTOR' : _CONTIRADAROBS,
  '__module__' : 'modules.drivers.proto.conti_radar_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.ContiRadarObs)
  })
_sym_db.RegisterMessage(ContiRadarObs)

ContiRadar = _reflection.GeneratedProtocolMessageType('ContiRadar', (_message.Message,), {
  'DESCRIPTOR' : _CONTIRADAR,
  '__module__' : 'modules.drivers.proto.conti_radar_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.ContiRadar)
  })
_sym_db.RegisterMessage(ContiRadar)


# @@protoc_insertion_point(module_scope)
